@@ -69,7 +69,7 @@ step_to_chull <- function(obj) {
       cat("\n")
       cat("    Using adjusted observed sufficient statistics vector with gamma = ")
       cat(round(obj$est$gamma, digits = 4))
-      cat(". L1 norm of difference between observation and adjusted observation: ")
+      cat(". \nL1 norm of difference between observation and adjusted observation: ")
       L1_diff <- sum(abs(obj$net$obs_stats_step - obj$net$obs_stats))
       if (round(L1_diff, digits = 3) < 0.001) { 
         cat("<0.001")
